@@ -15,6 +15,7 @@
 
 import math
 import blockdiag.DiagramMetrix
+from blockdiag import elements
 from blockdiag.utils.namedtuple import namedtuple
 from blockdiag.utils.XY import XY
 
@@ -49,6 +50,13 @@ class DiagramMetrix(blockdiag.DiagramMetrix.DiagramMetrix):
         metrix = super(DiagramMetrix, self).node(node)
         return NodeMetrix(node, metrix)
 
+    def cell(self, node):
+        if isinstance(node, elements.NodeGroup):
+            metrix = GroupMetrix(node, self)
+        else:
+            metrix = super(DiagramMetrix, self).cell(node)
+        return metrix
+
     def network(self, network):
         return NetworkMetrix(network, self)
 
@@ -125,7 +133,37 @@ class NodeMetrix(object):
                     dx = int(math.floor(base_x * m.cellSize * 2))
 
                 width = m.nodeWidth + m.spanWidth
-                textbox = [x + dx, y2 - m.spanHeight / 2, x + width, y2]
+                textbox = [x + dx - m.cellSize, y2 - m.spanHeight / 2,
+                           x + width, y2]
                 line = [XY(x + dx, y1), XY(x + dx, y2)]
 
                 yield Connector(network, line, textbox, [])
+
+
+class GroupMetrix(blockdiag.DiagramMetrix.NodeMetrix):
+    def __init__(self, node, metrix):
+        super(GroupMetrix, self).__init__(node, metrix)
+
+        self.is_root_group = False
+        if node.nodes:
+            network = min(node.nodes[0].networks, key=lambda n: n.xy.y)
+            if self.top().x == metrix.network(network).top().x:
+                self.is_root_group = True
+
+    def groupLabelBox(self):
+        box = super(GroupMetrix, self).groupLabelBox()
+        span = self.metrix.spanHeight / 2 - self.metrix.cellSize
+        box = (box[0], box[1] - span, box[2], box[3] - span)
+
+        if self.is_root_group:
+            width = box[2] - box[1]
+            box = (box[0] + width / 2, box[1], box[2], box[3])
+
+        return box
+
+    def marginBox(self):
+        box = super(GroupMetrix, self).marginBox()
+        margin_x = self.metrix.spanHeight / 2
+        margin_y = self.metrix.cellSize
+        return (box[0] - margin_y, box[1] - margin_x,
+                box[2] + margin_y, box[3] + margin_x)
