@@ -142,9 +142,22 @@ class DiagramLayoutManager:
             y2 = max(networks.index(g) for g in node.networks)
 
             if node.group and node.group != self.diagram:
-                starts = max(n.xy.x for n in node.group.nodes)
+                starts = min(n.xy.x for n in node.group.nodes)
             else:
+                nw = [n for n in node.networks if n.xy.y == y1][0]
+                nodes = [n for n in self.diagram.nodes if nw in n.networks]
+                layouted = [n for n in nodes  if n.xy.x > 0]
+
                 starts = 0
+                if layouted:
+                    basenode = min(layouted, key=lambda n: n.xy.x)
+                    if basenode.xy.y == y1:
+                        starts = basenode.xy.x + 1
+                    else:
+                        starts = basenode.xy.x + 1 - len(nodes)
+
+                if starts < 0:
+                    starts = 0
 
             for x in range(starts, len(self.diagram.nodes)):
                 points = [XY(x, y) for y in range(y1, y2 + 1)]
